Installation
============

The recommended way to install ``django-icons`` is to use ``pip``::

    $ pip install django-icons

Alternatively, you can install download or clone this repo and install from its folder with::

    $ pip install -e .

In your project, you should add ``django-icons`` to your ``requirements.txt``.

Be sure to use ``virtualenv`` if you develop python projects.

Add to INSTALLED_APPS in your ``settings.py``:

   ``'django_icons',``

After installation, the :doc:`quickstart` will get you on your way to using ``django-icons``.
